searchNodes=[{"doc":"Xod Parsing and schema validation library for Elixir Introduction Xod is a dynamic parsing and schema validation library for Elixir inspired by the Typescript library Zod . A schema refers broadly to a specification used to validate and transform any value, from a simple number to a complex nested object. Xod provides a functional API. The default schemata have no side effects and use only immutable state. Xod is also extensible. Apart from using the helper schemata provided, one can implement the Xod.Schema protocol to create a fully custom schema. Example iex&gt; alias Xod , as : X iex&gt; my_config = X . map ( %{ ...&gt; data : X . map ( %{ ...&gt; age : X . number ( int : true , ge : 0 , lt : 150 ) ...&gt; } ) , ...&gt; names : X . list ( X . string ( ) |&gt; X . max ( 10 ) ) ...&gt; } , key_coerce : true ) iex&gt; X . parse ( my_config , %{ ...&gt; &quot;data&quot; =&gt; %{ ...&gt; age : - 10 , ...&gt; } , ...&gt; names : [ &quot;John&quot; , &quot;Peter&quot; , &quot;Chandragupta&quot; ] ...&gt; } ) { :error , % Xod.XodError { issues : [ [ type : :too_small , path : [ :data , :age ] , message : &quot;Number must be greater than or equal to 0&quot; , data : [ min : 0 ] ] , [ type : :too_big , path : [ :names , 2 ] , message : &quot;String must contain at most 10 character(s)&quot; , data : [ max : 10 ] ] ] } } Alternatives NimbleOptions https://github.com/dashbitco/nimble_options Very popular library. Validates options defined as keyword lists. Optimal https://github.com/albert-io/optimal Similar to NimbleOptions. Only useful on opts defined as keyword lists. Parameter https://github.com/phcurado/parameter Schema creation, validation with serialization and deserialization. Works with maps by defining parameters on modules using macros. Xema https://github.com/hrzndhrn/xema Schema validator. Very similar to this project but inspired by JSON schema. License This software is licensed under the MIT license .","ref":"Xod.html","title":"Xod","type":"module"},{"doc":"Schema that matches with any value Example iex&gt; Xod . parse Xod . list ( Xod . any ( ) ) , [ 1 , &quot;string&quot; , :atom , [ ] ] { :ok , [ 1 , &quot;string&quot; , :atom , [ ] ] }","ref":"Xod.html#any/0","title":"Xod.any/0","type":"function"},{"doc":"Schema for validationg booleans It accepts the following options: coerce :: boolean/0 — Coerce truthy or falsy values to boolean, defaults to false Examples iex&gt; Xod . parse Xod . boolean ( ) , true { :ok , true } iex&gt; Xod . parse! Xod . boolean ( ) , { 3.0 , &quot;abc&quot; } ** (Xod.XodError) Expected boolean, got tuple (in path [])","ref":"Xod.html#boolean/1","title":"Xod.boolean/1","type":"function"},{"doc":"Sets the foreign_keys option of the map to the provided schema See: Xod.map/2 Example iex&gt; my_schema = Xod . map ( %{ } ) |&gt; Xod . check_all ( Xod . number ( ) ) iex&gt; Xod . parse! ( my_schema , %{ key : &quot;abc&quot; } ) ** (Xod.XodError) Expected number, got string (in path [:key])","ref":"Xod.html#check_all/2","title":"Xod.check_all/2","type":"function"},{"doc":"Replaces provided value with default if nil before parsing with schema Example iex&gt; Xod . parse ( Xod . string ( ) |&gt; Xod . default ( &quot;foo&quot; ) , nil ) { :ok , &quot;foo&quot; } iex&gt; Xod . parse ( Xod . string ( ) |&gt; Xod . default ( &quot;foo&quot; ) , &quot;bar&quot; ) { :ok , &quot;bar&quot; }","ref":"Xod.html#default/2","title":"Xod.default/2","type":"function"},{"doc":"Set the ge option on a number schema See: Xod.number/1 Example iex&gt; Xod . parse! ( Xod . number ( ) |&gt; Xod . ge ( 10 ) , 9 ) ** (Xod.XodError) Number must be greater than or equal to 10 (in path [])","ref":"Xod.html#ge/2","title":"Xod.ge/2","type":"function"},{"doc":"Set the gt option on a number schema See: Xod.number/1 Example iex&gt; Xod . parse! ( Xod . number ( ) |&gt; Xod . gt ( 10 ) , 10 ) ** (Xod.XodError) Number must be greater than 10 (in path [])","ref":"Xod.html#gt/2","title":"Xod.gt/2","type":"function"},{"doc":"Set the int option on a number schema See: Xod.number/1 Example iex&gt; Xod . parse! ( Xod . number ( ) |&gt; Xod . int ( true ) , 11.5 ) ** (Xod.XodError) Expected integer, got float (in path [])","ref":"Xod.html#int/2","title":"Xod.int/2","type":"function"},{"doc":"Shorthand for Xod.list(Xod.never(), keys: keys) Takes the same options as Xod.list/2 Examples iex&gt; Xod . parse Xod . keyword ( [ x : Xod . number ( ) ] ) , [ x : 13.0 ] { :ok , [ x : 13.0 ] } iex&gt; Xod . parse! Xod . keyword ( [ { 0 , Xod . number ( ) } ] ) , [ &quot;abc&quot; ] ** (Xod.XodError) Expected number, got string (in path [0])","ref":"Xod.html#keyword/2","title":"Xod.keyword/2","type":"function"},{"doc":"Set the le option on a number schema See: Xod.number/1 Example iex&gt; Xod . parse! ( Xod . number ( ) |&gt; Xod . le ( 10 ) , 11 ) ** (Xod.XodError) Number must be smaller than or equal to 10 (in path [])","ref":"Xod.html#le/2","title":"Xod.le/2","type":"function"},{"doc":"Set the length option on a string schema See: Xod.string/1 Example iex&gt; Xod . parse! ( Xod . string ( ) |&gt; Xod . length ( 5 ) , &quot;1234&quot; ) ** (Xod.XodError) String must contain exactly 5 character(s) (in path []) iex&gt; Xod . parse! ( Xod . list ( Xod . number ( ) ) |&gt; Xod . length ( 3 ) , [ 1 , 2 , 3 , 4 ] ) ** (Xod.XodError) List must contain exactly 3 character(s) (in path [])","ref":"Xod.html#length/2","title":"Xod.length/2","type":"function"},{"doc":"Schema for validating lists Must pass an argument, which is the schema used to validate list items. It accepts the following options: keys :: keyword/0 — A list of key-or-index value pairs. They are used to match against list values instead of the element schema. max :: non_neg_integer/0 — Max length of the list (inclusive) min :: non_neg_integer/0 — Min length of the list (inclusive) length :: non_neg_integer/0 — Exact length of the list coerce :: boolean/0 — If true, when a map is provided it will be converted to a list. Defaults to true Examples iex&gt; Xod . parse Xod . list ( Xod . tuple ( { Xod . string ( ) , Xod . number ( ) } ) ) , [ { &quot;a&quot; , 13.0 } ] { :ok , [ { &quot;a&quot; , 13.0 } ] } iex&gt; Xod . parse! Xod . list ( Xod . number ( ) ) , [ [ ] , %{ } ] ** (Xod.XodError) Expected number, got list (in path [0]) Expected number , got map ( in path [ 1 ] )","ref":"Xod.html#list/2","title":"Xod.list/2","type":"function"},{"doc":"Schema that only matches a specific value It accepts the following options: strict :: boolean/0 — Whether to use the strict equality operator ===/2 . Defaults to false Example iex&gt; Xod . parse Xod . literal ( 10 ) , 10.0 { :ok , 10.0 } iex&gt; Xod . parse! Xod . literal ( 10 , strict : true ) , 10.0 ** (Xod.XodError) Invalid literal value, expected 10 (in path [])","ref":"Xod.html#literal/2","title":"Xod.literal/2","type":"function"},{"doc":"Set the lt option on a number schema See: Xod.number/1 Example iex&gt; Xod . parse! ( Xod . number ( ) |&gt; Xod . lt ( 10 ) , 10 ) ** (Xod.XodError) Number must be smaller than 10 (in path [])","ref":"Xod.html#lt/2","title":"Xod.lt/2","type":"function"},{"doc":"Schema for validating maps Must pass an argument, which is a map values to schemata. It accepts the following options: foreign_keys :: Xod.Map.foreign_keys/0 — This option determines what happens when there are unknown keys in the map. If set to :strip, the entries are dropped; if set to :strict, an error is returned; if set to passthrough, the entries are included as is ; and if set to a schema, it is used to parse and validate each entry. coerce :: boolean/0 — If true, when a list is parsed, it is converted to a map using the following algorithm: if an item is a 2-tuple, it is included as a key-value pair; if not, the index is used as key. Defaults to true key_coerce :: boolean/0 — If true, not only are the passed keys checked, but also their string representations. This is useful to transform string keys into atom keys without creating atoms at runtime. Defaults to false struct :: module/0 | struct/0 — If provided, map will be converted to struct after parsing Examples iex&gt; Xod . parse ( ...&gt; Xod . map ( %{ my_key : Xod . number ( ) , other : Xod . string ( ) } , key_coerce : true ) , ...&gt; %{ &quot;my_key&quot; =&gt; 13 , other : &quot;bar baz&quot; } ) { :ok , %{ my_key : 13 , other : &quot;bar baz&quot; } } iex&gt; Xod . parse! Xod . map ( %{ x : Xod . number ( ) } ) , %{ x : true } ** (Xod.XodError) Expected number, got boolean (in path [:x])","ref":"Xod.html#map/2","title":"Xod.map/2","type":"function"},{"doc":"Set the max option on a string or list schema See: Xod.string/1 and Xod.list/2 Example iex&gt; Xod . parse! ( Xod . string ( ) |&gt; Xod . max ( 4 ) , &quot;12345&quot; ) ** (Xod.XodError) String must contain at most 4 character(s) (in path []) iex&gt; Xod . parse! ( Xod . list ( Xod . number ( ) ) |&gt; Xod . max ( 4 ) , [ 1 , 2 , 3 , 4 , 5 ] ) ** (Xod.XodError) List must contain at most 4 character(s) (in path [])","ref":"Xod.html#max/2","title":"Xod.max/2","type":"function"},{"doc":"Set the min option on a string or list schema See: Xod.string/1 and Xod.list/2 Example iex&gt; Xod . parse! ( Xod . string ( ) |&gt; Xod . min ( 5 ) , &quot;1234&quot; ) ** (Xod.XodError) String must contain at least 5 character(s) (in path []) iex&gt; Xod . parse! ( Xod . list ( Xod . number ( ) ) |&gt; Xod . min ( 5 ) , [ 1 , 2 , 3 , 4 ] ) ** (Xod.XodError) List must contain at least 5 character(s) (in path [])","ref":"Xod.html#min/2","title":"Xod.min/2","type":"function"},{"doc":"Changes a number schema to only match negative values See: Xod.number/1 Example iex&gt; Xod . parse! ( Xod . number ( ) |&gt; Xod . negative ( ) , 0 ) ** (Xod.XodError) Number must be smaller than 0 (in path [])","ref":"Xod.html#negative/1","title":"Xod.negative/1","type":"function"},{"doc":"Schema that never matches any value Example iex&gt; Xod . parse! ( Xod . never ( ) , :some_value ) ** (Xod.XodError) Expected never, got atom (in path [])","ref":"Xod.html#never/0","title":"Xod.never/0","type":"function"},{"doc":"Changes a list or string schema to only match non-empty values See: Xod.string/1 and Xod.list/2 Example iex&gt; Xod . parse! ( Xod . string ( ) |&gt; Xod . nonempty ( ) , &quot;&quot; ) ** (Xod.XodError) String must contain at least 1 character(s) (in path [])","ref":"Xod.html#nonempty/1","title":"Xod.nonempty/1","type":"function"},{"doc":"Changes a number schema to only match non-negative values See: Xod.number/1 Example iex&gt; Xod . parse! ( Xod . number ( ) |&gt; Xod . nonnegative ( ) , - 1 ) ** (Xod.XodError) Number must be greater than or equal to 0 (in path [])","ref":"Xod.html#nonnegative/1","title":"Xod.nonnegative/1","type":"function"},{"doc":"Changes a number schema to only match non-positive values See: Xod.number/1 Example iex&gt; Xod . parse! ( Xod . number ( ) |&gt; Xod . nonpositive ( ) , 1 ) ** (Xod.XodError) Number must be smaller than or equal to 0 (in path [])","ref":"Xod.html#nonpositive/1","title":"Xod.nonpositive/1","type":"function"},{"doc":"Schema for validating numbers It accepts the following options: lt :: number/0 — Check number is less than value le :: number/0 — Check number is less than or equal to value gt :: number/0 — Check number is greater than value ge :: number/0 — Check number is greater than or equal to value int :: boolean/0 — Whether number must be integer, defaults to false step :: integer/0 — Check number is multiple of value. Implies int Examples iex&gt; Xod . parse Xod . number ( ) , 175.3 { :ok , 175.3 } iex&gt; Xod . parse! Xod . number ( ) , nil ** (Xod.XodError) Expected number, got nil (in path [])","ref":"Xod.html#number/1","title":"Xod.number/1","type":"function"},{"doc":"Parses and validates value using the provided schema On success, returns {:ok, value} with the parsed value. On error, returns {:error, error} where error is a Xod.XodError","ref":"Xod.html#parse/2","title":"Xod.parse/2","type":"function"},{"doc":"Parses and validates value using the provided schema Like Xod.parse/2 , but just returns the value and raises in case of a validation error.","ref":"Xod.html#parse!/2","title":"Xod.parse!/2","type":"function"},{"doc":"Changes a number schema to only match positive values See: Xod.number/1 Example iex&gt; Xod . parse! ( Xod . number ( ) |&gt; Xod . positive ( ) , 0 ) ** (Xod.XodError) Number must be greater than 0 (in path [])","ref":"Xod.html#positive/1","title":"Xod.positive/1","type":"function"},{"doc":"Set the regex option on a string schema See: Xod.string/1 Example iex&gt; Xod . parse! ( Xod . string ( ) |&gt; Xod . regex ( ~r/ab*c?d/ ) , &quot;abbczz&quot; ) ** (Xod.XodError) Invalid string: regex didn&#39;t match (in path [])","ref":"Xod.html#regex/2","title":"Xod.regex/2","type":"function"},{"doc":"Gets the underlying schema map Example iex&gt; my_schema = Xod . map %{ x : Xod . boolean ( ) } iex&gt; Xod . shape my_schema %{ x : % Xod.Boolean { } }","ref":"Xod.html#shape/1","title":"Xod.shape/1","type":"function"},{"doc":"Set the step option on a number schema See: Xod.number/1 Example iex&gt; Xod . parse! ( Xod . number ( ) |&gt; Xod . step ( 2 ) , 11 ) ** (Xod.XodError) Number must be multiple of 2 (in path [])","ref":"Xod.html#step/2","title":"Xod.step/2","type":"function"},{"doc":"Schema for validating strings It accepts the following options: validate :: boolean/0 — Check string is valid UTF-8, defaults to true max :: non_neg_integer/0 — Max length of the string (inclusive) min :: non_neg_integer/0 — Min length of the string (inclusive) length :: non_neg_integer/0 — Exact length of the string regex :: Regex.t/0 — Regular expression the string must match Examples iex&gt; Xod . parse Xod . string ( ) , &quot;foo bar&quot; { :ok , &quot;foo bar&quot; } iex&gt; Xod . parse! Xod . string ( ) , 13.0 ** (Xod.XodError) Expected string, got number (in path [])","ref":"Xod.html#string/1","title":"Xod.string/1","type":"function"},{"doc":"Applies the passed closure to the result of the schema, if it validates Example iex&gt; int_string_schema = Xod . number ( int : true ) ...&gt; |&gt; Xod . transform ( &amp; to_string / 1 ) iex&gt; Xod . parse ( int_string_schema , 27 ) { :ok , &quot;27&quot; }","ref":"Xod.html#transform/2","title":"Xod.transform/2","type":"function"},{"doc":"Schema for validating tuples Must pass argument, which is a tuple of other schemata It accepts the following options: coerce :: boolean/0 — Coerce lists into tuples, defaults to true Examples iex&gt; Xod . parse Xod . tuple ( { Xod . number ( ) , Xod . number ( ) } ) , { 5 , 8 } { :ok , { 5 , 8 } } iex&gt; Xod . parse! Xod . tuple ( { Xod . number ( ) , Xod . number ( ) } ) , %{ 0 =&gt; 5 , 1 =&gt; 8 } ** (Xod.XodError) Expected tuple, got map (in path []) iex&gt; Xod . parse! Xod . tuple ( { Xod . number ( ) , Xod . number ( ) } ) , { 1 , [ ] } ** (Xod.XodError) Expected number, got list (in path [1])","ref":"Xod.html#tuple/2","title":"Xod.tuple/2","type":"function"},{"doc":"Schema that validates value against a list of schemata and succeeds if at least one matches. Example iex&gt; Xod . parse ( Xod . list ( Xod . union ( [ Xod . string ( ) , Xod . number ( ) ] ) ) , [ &quot;abc&quot; , 4 , &quot;t&quot; ] ) { :ok , [ &quot;abc&quot; , 4 , &quot;t&quot; ] } iex(5)&gt; Xod . parse ( Xod . union ( [ Xod . string ( ) , Xod . number ( ) ] ) , :atom ) { :error , % Xod.XodError { issues : [ type : :invalid_union , path : [ ] , message : &quot;Invalid input&quot; , data : [ union_errors : [ % Xod.XodError { issues : [ [ type : :invalid_type , path : [ ] , data : [ expected : :string , got : :atom ] , message : &quot;Expected string, got atom&quot; ] ] } , % Xod.XodError { issues : [ [ type : :invalid_type , path : [ ] , data : [ expected : :number , got : :atom ] , message : &quot;Expected number, got atom&quot; ] ] } ] ] ] } }","ref":"Xod.html#union/1","title":"Xod.union/1","type":"function"},{"doc":"Set the validate option on a string schema See: Xod.string/1 Example iex&gt; Xod . parse! ( Xod . string ( ) |&gt; Xod . validate ( false ) , &lt;&lt; 0xFFFF :: 16 &gt;&gt; ) &lt;&lt; 0xFFFF :: 16 &gt;&gt;","ref":"Xod.html#validate/2","title":"Xod.validate/2","type":"function"},{"doc":"","ref":"Xod.Any.html","title":"Xod.Any","type":"module"},{"doc":"","ref":"Xod.Any.html#new/0","title":"Xod.Any.new/0","type":"function"},{"doc":"","ref":"Xod.Any.html#t:t/0","title":"Xod.Any.t/0","type":"type"},{"doc":"","ref":"Xod.Boolean.html","title":"Xod.Boolean","type":"module"},{"doc":"","ref":"Xod.Boolean.html#new/1","title":"Xod.Boolean.new/1","type":"function"},{"doc":"","ref":"Xod.Boolean.html#t:t/0","title":"Xod.Boolean.t/0","type":"type"},{"doc":"","ref":"Xod.Common.html","title":"Xod.Common","type":"module"},{"doc":"","ref":"Xod.Common.html#set_fields/1","title":"Xod.Common.set_fields/1","type":"macro"},{"doc":"","ref":"Xod.Common.html#t:path/0","title":"Xod.Common.path/0","type":"type"},{"doc":"","ref":"Xod.Common.html#t:result/1","title":"Xod.Common.result/1","type":"type"},{"doc":"","ref":"Xod.Common.html#t:type_atom/0","title":"Xod.Common.type_atom/0","type":"type"},{"doc":"","ref":"Xod.Default.html","title":"Xod.Default","type":"module"},{"doc":"","ref":"Xod.Default.html#new/2","title":"Xod.Default.new/2","type":"function"},{"doc":"","ref":"Xod.Default.html#t:t/0","title":"Xod.Default.t/0","type":"type"},{"doc":"","ref":"Xod.List.html","title":"Xod.List","type":"module"},{"doc":"","ref":"Xod.List.html#keys/2","title":"Xod.List.keys/2","type":"function"},{"doc":"","ref":"Xod.List.html#length/2","title":"Xod.List.length/2","type":"function"},{"doc":"","ref":"Xod.List.html#max/2","title":"Xod.List.max/2","type":"function"},{"doc":"","ref":"Xod.List.html#min/2","title":"Xod.List.min/2","type":"function"},{"doc":"","ref":"Xod.List.html#new/2","title":"Xod.List.new/2","type":"function"},{"doc":"","ref":"Xod.List.html#t:args/0","title":"Xod.List.args/0","type":"type"},{"doc":"","ref":"Xod.List.html#t:t/0","title":"Xod.List.t/0","type":"type"},{"doc":"","ref":"Xod.Literal.html","title":"Xod.Literal","type":"module"},{"doc":"","ref":"Xod.Literal.html#new/2","title":"Xod.Literal.new/2","type":"function"},{"doc":"","ref":"Xod.Literal.html#t:t/0","title":"Xod.Literal.t/0","type":"type"},{"doc":"","ref":"Xod.Map.html","title":"Xod.Map","type":"module"},{"doc":"","ref":"Xod.Map.html#check_all/2","title":"Xod.Map.check_all/2","type":"function"},{"doc":"","ref":"Xod.Map.html#new/2","title":"Xod.Map.new/2","type":"function"},{"doc":"","ref":"Xod.Map.html#shape/1","title":"Xod.Map.shape/1","type":"function"},{"doc":"","ref":"Xod.Map.html#t:foreign_keys/0","title":"Xod.Map.foreign_keys/0","type":"type"},{"doc":"","ref":"Xod.Map.html#t:t/0","title":"Xod.Map.t/0","type":"type"},{"doc":"","ref":"Xod.Never.html","title":"Xod.Never","type":"module"},{"doc":"","ref":"Xod.Never.html#new/0","title":"Xod.Never.new/0","type":"function"},{"doc":"","ref":"Xod.Never.html#t:t/0","title":"Xod.Never.t/0","type":"type"},{"doc":"","ref":"Xod.Number.html","title":"Xod.Number","type":"module"},{"doc":"","ref":"Xod.Number.html#ge/2","title":"Xod.Number.ge/2","type":"function"},{"doc":"","ref":"Xod.Number.html#gt/2","title":"Xod.Number.gt/2","type":"function"},{"doc":"","ref":"Xod.Number.html#int/2","title":"Xod.Number.int/2","type":"function"},{"doc":"","ref":"Xod.Number.html#le/2","title":"Xod.Number.le/2","type":"function"},{"doc":"","ref":"Xod.Number.html#lt/2","title":"Xod.Number.lt/2","type":"function"},{"doc":"","ref":"Xod.Number.html#negative/1","title":"Xod.Number.negative/1","type":"function"},{"doc":"","ref":"Xod.Number.html#new/1","title":"Xod.Number.new/1","type":"function"},{"doc":"","ref":"Xod.Number.html#nonnegative/1","title":"Xod.Number.nonnegative/1","type":"function"},{"doc":"","ref":"Xod.Number.html#nonpositive/1","title":"Xod.Number.nonpositive/1","type":"function"},{"doc":"","ref":"Xod.Number.html#positive/1","title":"Xod.Number.positive/1","type":"function"},{"doc":"","ref":"Xod.Number.html#step/2","title":"Xod.Number.step/2","type":"function"},{"doc":"","ref":"Xod.Number.html#t:t/0","title":"Xod.Number.t/0","type":"type"},{"doc":"","ref":"Xod.Schema.html","title":"Xod.Schema","type":"protocol"},{"doc":"","ref":"Xod.Schema.html#parse/3","title":"Xod.Schema.parse/3","type":"function"},{"doc":"","ref":"Xod.Schema.html#t:t/0","title":"Xod.Schema.t/0","type":"type"},{"doc":"","ref":"Xod.String.html","title":"Xod.String","type":"module"},{"doc":"","ref":"Xod.String.html#length/2","title":"Xod.String.length/2","type":"function"},{"doc":"","ref":"Xod.String.html#max/2","title":"Xod.String.max/2","type":"function"},{"doc":"","ref":"Xod.String.html#min/2","title":"Xod.String.min/2","type":"function"},{"doc":"","ref":"Xod.String.html#new/1","title":"Xod.String.new/1","type":"function"},{"doc":"","ref":"Xod.String.html#regex/2","title":"Xod.String.regex/2","type":"function"},{"doc":"","ref":"Xod.String.html#validate/2","title":"Xod.String.validate/2","type":"function"},{"doc":"","ref":"Xod.String.html#t:args/0","title":"Xod.String.args/0","type":"type"},{"doc":"","ref":"Xod.String.html#t:t/0","title":"Xod.String.t/0","type":"type"},{"doc":"","ref":"Xod.Transform.html","title":"Xod.Transform","type":"module"},{"doc":"","ref":"Xod.Transform.html#new/2","title":"Xod.Transform.new/2","type":"function"},{"doc":"","ref":"Xod.Transform.html#t:t/0","title":"Xod.Transform.t/0","type":"type"},{"doc":"","ref":"Xod.Tuple.html","title":"Xod.Tuple","type":"module"},{"doc":"","ref":"Xod.Tuple.html#new/2","title":"Xod.Tuple.new/2","type":"function"},{"doc":"","ref":"Xod.Tuple.html#t:t/0","title":"Xod.Tuple.t/0","type":"type"},{"doc":"","ref":"Xod.Union.html","title":"Xod.Union","type":"module"},{"doc":"","ref":"Xod.Union.html#new/1","title":"Xod.Union.new/1","type":"function"},{"doc":"","ref":"Xod.Union.html#t:t/0","title":"Xod.Union.t/0","type":"type"},{"doc":"An error encountered during schema validation.","ref":"Xod.XodError.html","title":"Xod.XodError","type":"exception"},{"doc":"The error struct. issues contains a list of issues encountered while validating a schema","ref":"Xod.XodError.html#__struct__/0","title":"Xod.XodError.__struct__/0","type":"function"},{"doc":"","ref":"Xod.XodError.html#invalid_type/3","title":"Xod.XodError.invalid_type/3","type":"function"},{"doc":"","ref":"Xod.XodError.html#t:issue/0","title":"Xod.XodError.issue/0","type":"type"},{"doc":"","ref":"Xod.XodError.html#t:t/0","title":"Xod.XodError.t/0","type":"type"}]